Occupancy probability of each node in each site considering a kernel density funcion
comp_kernel_gravel.RdOccupancy probability of each node in each site considering a kernel density funcion
Arguments
- x
Node by communities matrix
- phy
phylo object
- coords
Data frame with two columns containing spatial coordinate of communities
- w_slope
A scalar representing the slope of the dispersal kernel function. This is the same as passed to
calc_sbearsfunction- min_disp_prob
A scalar between 0 and 1 representing the minimum probability of receiving an immigrant node from a focal cell. Same as passed to
calc_sbearsfunction